@@ -13,15 +13,22 @@ class BaseContext(object):
     origin: str = dataclasses.field(init=False)
     sign_type: SignType = dataclasses.field(init=False)
     chain: Chain = dataclasses.field(init=False)
-    
+    domain: str = dataclasses.field(init=False)
+
     def __post_init__(self):
         self.origin = self.get_origin(self.action.origin)
+        self.domain = self.get_domain(self.origin)
     
     def get_origin(self, origin):
         if not origin:
             return ''
         return origin.rstrip('/')
 
+    def get_domain(self, origin):
+        if not origin:
+            return ''
+        return urlparse(origin).netloc
+
 
 @dataclasses.dataclass()
 class TextContext(BaseContext):
